@@ -1,7 +1,9 @@
-# -*- coding: utf-8 -*-
-
+import functools
 import warnings
 
+from django.template.loader import render_to_string
+from django.utils.safestring import mark_safe
+
 
 # Global register dict for third party
 # template functions, filters and extensions.
@@ -9,6 +11,7 @@ _local_env = {
     "globals": {},
     "tests": {},
     "filters": {},
+    "extensions": set([]),
 }
 
 
@@ -22,6 +25,9 @@ def _update_env(env):
     env.tests.update(_local_env["tests"])
     env.filters.update(_local_env["filters"])
 
+    for extension in _local_env["extensions"]:
+        env.add_extension(extension)
+
 
 def _attach_function(attr, func, name=None):
     if name is None:
@@ -52,6 +58,12 @@ def _register_function(attr, name=None, fn=None):
     raise RuntimeError("Invalid parameters")
 
 
+def extension(extension):
+    global _local_env
+    _local_env["extensions"].add(extension)
+    return extension
+
+
 def global_function(*args, **kwargs):
     return _register_function("globals", *args, **kwargs)
 
@@ -64,24 +76,20 @@ def filter(*args, **kwargs):
     return _register_function("filters", *args, **kwargs)
 
 
-class Library(object):
-    def __init__(self):
-        warnings.warn("Use Library class is deprecated and will be removed "
-                      "in future versions", DeprecationWarning, stacklevel=2)
+def render_with(template, fn=None):
+    """
+    Makes simple function works like
+    django's default inclusion_tag: render
+    specified template with context returned
+    by decorated function.
+    """
 
-    def global_function(self, *args, **kwargs):
-        return _register_function("globals", *args, **kwargs)
+    if fn is None:
+        return functools.partial(render_with, template)
 
-    def test(self, *args, **kwargs):
-        return _register_function("tests", *args, **kwargs)
+    @functools.wraps(fn)
+    def _wrapper(*args, **kwargs):
+        data = render_to_string(template, fn(*args, **kwargs))
+        return mark_safe(data)
 
-    def filter(self, *args, **kwargs):
-        return _register_function("filters", *args, **kwargs)
-
-    def __setitem__(self, item, value):
-        _env = _get_env()
-        _env.globals[item] = value
-
-    def __getitem__(self, item, value):
-        _env = _get_env()
-        return _env.globals[item]
+    return _wrapper
